# tkinterDev

`tkinter`高级工具包，实现了许多高级功能，我会持续更新的。😁😁😁

关于文档的更多内容请查看[我的主页](https:/xiangqinxi.github.io/tkinterDev/%E5%AE%89%E8%A3%85/)
关于超详细文档请查看[tkinterDev Docs](https://tkdev-docs.netlify.app/)
____
## 依赖问题
这个库拥有许多好用的功能，但是很多功能的代价就是需要依赖库，如果想要体验到完整内容就可以使用pip下载以下所有的库。

- [pywin32](https://pypi.org/project/pywin/) 实现诸多高级功能需要的
- [win32mica](https://pypi.org/project/win32mica/) 实现云母高级特效需要的
- [BlurWindow](https://pypi.org/project/BlurWindow/) 实现亚克力高级特效需要的
- [darkdetect](https://pypi.org/project/darkdetect/) 用于检测是否是深色主题或是浅色主题
- [Deprecated](https://pypi.org/project/Deprecated/) 用于标记一些废弃的组件
- [tkcap](https://pypi.org/project/tkcap) 用于截取窗口图片
```bash
pip install pywin32
```
```bash
pip install win32mica
```
```bash
pip install BlurWindow
```
```bash
pip install darkdetect
```
```bash
pip install tkcap
```
```bash
pip install Deprecated
```
____
## 版本信息
请使用最新的稳定版，虽然最新版可以用，但不排除会出现一些不可免得错误，大版本更新有时会出现BUG，但是小版本可以考虑，因为小版本是对大版本的优化和改正，请按照下方标准进行安装。🐋🐳🐋🐳
- 不稳定版本 1.0.0 - 1.5.0 1.8.3 - 1.8.4 2.2.2
- 最新稳定版本 3.1.0
- 最低稳定版本 1.6.0
 
1.6.0 稳定版发布。

1.7.0 功能补充，添加`DevAppBar`模块。

1.8.0 `DevDrag`优化，预添加组件`DevAccumulatorButton`、`DevDocs`、`DevResize`（在以后可能会删除的组件）。

1.8.1 `DevWindow`优化，加入标题栏后，可显示在任务栏内。

1.8.2 `DevTitleBar`修正标题按钮放大按钮，删去最小化按钮的函数，因为最小化后就找不到窗口了，任务栏中的窗口也不见了，所以等以后尝试改正。

1.8.3 `DevTitleBar`优化。

1.8.4 `DevToplevel`修正。

1.8.5 `DevTitleBar`修正，真的最后一次修正了！

1.8.6 `DevWindow`优化，可以选择是否将窗口显示在任务栏。

1.8.7 `DevWindow`优化，可以使用`centre()`将窗口居中。

1.8.8 `DevTitleBar`优化，双击窗口放大。

1.9.0 正式稳定更新，组件参数各种优化，添加`DevSideBar`组件。

1.9.1 文档改正。

1.9.2 `DevTitleBar`修正最大化按钮和最小化按钮的的事件特征。

2.0.0 添加`DevResize`，可以通过`DevResize`来移动组件。

2.0.1 修正`DevResize`，在组件被消除时，将会批次销毁按钮组件

2.0.2 修改一些BUG，添加`DevObject`组件，用于管理组件。

2.0.3 修正错误。

2.0.4 修正错误。

2.0.6 添加图标，从tkdev.devicon里导入

2.1.0 优化代码，去除大量的windll代码，改用win32代码。添加window_custom函数，window参数输入tkinter.Tk窗口，即可使用win32去除窗口（因为可以用overrideredirect来自定义），所以还是摆在那，想用就用。添加window_embed函数，window填入tkinter.Tk窗口，toplevel填入tkinter.Toplevel窗口，即可使用系统的嵌套子系统。

2.1.1 添加window_custom_border_taskbar可以实现真正的自定义窗口。

2.1.2 添加window_minbox、window_maxbox。

2.1.3 添加devcore.DevSysTray组件，需安装pystray库使用

2.1.4 修正BUG

2.1.5 添加Stack组件

2.1.6 添加window_pos方法，可以快速移动窗口位置。添加taskbar_height参数快速获取任务栏高度。

2.1.7 添加devwin包，里面将是使用win32开发的组件。WinMDIWindow组件可以将TopLevel组件嵌入容器

2.2.0 添加devdraw包，使用Canvas进行绘画，现已做好DrawButton组件。并修改了一些默认值

2.2.1 导入win32mica库，添加DevWindow方法mica()启用云母效果，此功能仅在Windows11上可用。

2.2.2 更多功能实现 🚫（有严重BUG请勿使用）

2.3.0 严重BUG修正，请勿使用2.2.2版本。请勿同时使用mica()和acrylic()，如果需要，那么请将mica特效排在前面，acrylic排在后面，否则会出现不兼容的情况。

2.3.1 BUG修复

2.3.2 添加一键安装所有依赖库的功能，Install_ALL()

2.3.3 对亚克力特效的低配适配，在使用时加入low=True。

2.3.4 改进代码，修复在未装依赖库之前发生的错误

2.3.5 改进代码，添加DevWindow的方法screenshot()。

2.3.6 添加devnet包，则是从网上资料里找到的库

2.3.7 在使用Install_ALL时安装win32mica库时检测是否是Windows11系统，如果是Windows11系统就下载win32mica库

2.3.8 弃用DevTitleBar，请使用DevHeaderBar

2.3.9 开启实验性组件，devpre库，DevPreTooltip实现不依赖tkinter-tooltip库的自主开发的组件

2.3.10 devpre库新增DevPreToolbox组件，用于操作调试窗口的工具箱。新增DevTabber组件，将他放在窗口下方，用于切换界面。并改进了devcore.DevAction的其他参数。

2.3.11 添加tkdev-docs，但未完善，请等待更新

2.3.12 添加Uninstall、UpGrade

2.4.0 修复DevPreTooltip组件, 修复window_border无效窗柄的错误

2.4.1 重写DevPreTooltip组件，将它显示方式改成放在组件上几秒后显示在组件的下方

2.4.2 修复BUG

2.4.3 标注文档

2.4.4 Install、UpGrade添加安装预览版的选项

2.4.5 修复BUG

2.4.6 将DevTooltip删除，使用devpre中DevPreTooltip替换，去除tkinter-tooltip的依赖

2.4.7 修复BUG

2.4.8 移除devnet

2.5.0 BUG修复

2.5.1 添加Package供于打包文件

2.5.2 修复Package错误

3.0.0 补充文档。

3.0.1 补充注释。

3.0.2 补充注释

3.0.3 devpre库DevPreToolbox更新

3.0.4 添加组件DevTray，可以通过`from tkdev.winico import DevTray`导入

3.0.5 DevTray改进。

3.0.6 DevTray改进，补充注释

3.0.7 BUG修复。

3.0.8 DevTray添加回调Icon。添加add，modify，delete选项。改进DevTray

3.0.9 DevTray添加回调Icon_ID。

3.1.0 DevHeaderBar添加add_title()选项，可以用于添加标题。
DevWindow添加create_titlebar()选项，快速创建窗口，添加create_tray()选项快速添加托盘图标

3.1.1 `winico.download_winico()`可以自动检测是不是64位系统，并安装对应的64位或是32位版本的Winico

3.1.2 添加`devplyer`库，使用plyer开发的工具库。

3.1.3 修复BUG。

3.2.0 添加初始化，在终端输入`python -m tkdev`即可初始化。

3.2.1 winico库更名为devtcl，将改为tcl的扩展库支持。

3.2.2 正在开发DevTwApi。

3.2.3 初始化添加twApi库。

3.3.0 开发DevManage组件，优化初始化界面界面进度条。

3.3.1 将是3.x的最后一个版本，请使用tkinterDev-Stable库。,
____
